package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M35J0``,````$````__\``+@`````````0```````````````````````````
M````````````````````\`````X?N@X`M`G-(;@!3,TA5&AI<R!P<F]G<F%M
M(&-A;FYO="!B92!R=6X@:6X@1$]3(&UO9&4N#0T*)``````````"PDJ=1J,D
MSD:C),Y&HR3.Q;\JSD2C),ZNO"#.1*,DSB2\-\Y"HR3./;\HSD2C),Y&HR7.
M%*,DSKF#(,Y%HR3.KKPNSDNC),[^I2+.1Z,DSE)I8VA&HR3.````````````
M````````````````````4$4``$P!!`!)\Y%(``````````#@``\!"P$&```P
M````H````````+`Y````$````$``````0```$````!````0`````````!```
M````````X````!```)4?`0`#```````0```0`````!```!`````````0````
M``````````#,FP``9`````#```#0$0``````````````````````````````
M````,$$``!P`````````````````````````````````````````````````
M`````````$```"P!```````````````````````````````````N=&5X=```
M`.PJ````$````#`````0```````````````````@``!@+G)D871A``#*80``
M`$````!P````0```````````````````0```0"YD871A````9`0```"P````
M$````+```````````````````$```,`N<G-R8P```-`1````P````"````#`
M``````````````````!```#`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%:^B$%``%9HPCA``&AL04``Z*8H``!0Z)HH``"#Q!!6:+`X0`!H5$%``.B-
M*```4.B!*```@\007L-5B^R![`@$``!35E=HL$%``.BH`0``B47\C87X^___
MQP0D``0``#/;4%/_%0A`0`"%P`^%3`$``/\U$+!``(MU"%;_%8A`0`!9687`
M5G03:*!!0`#H\P$``%F+QEGI5P$``.C%*```_S44L$``BSV00$``B47X_W4,
M_]>#Q`R+\#OS#X0?`0``.!YU!;Z<04``.5W\=!-6_W7\Z(<H``!9A<!9#X3+
M````5NA]*```BE0P_UF+#1"P0``Z$74*2(@<!HI4!O_K[(M5^/]U"(U$$`$]
M``0```^-S0```%%6C87X^___:)1!0`!0_Q680$``Z(PG``!0Z)@G``"+,.A_
M)P``4.B%)P``@\0<4(V%^/O__U#H:2<``%#H=2<``%G_,/]64(/$#(7`=4CH
M42<``%#H5R<``&:+0`999B4`\&8]`(!U+N@W)P``4.A#)P``BS!9C87X^___
M:@%0Z"`G``!0Z"PG``!9_S#_%H/$#(7`=!#_-12P0`!3_]=96>GZ_O__C87X
M^___4&B@04``Z+<```"-A?C[__]0_Q5$0$``@\0,ZQ+_=0AHH$%``.B8````
MBT4(65E?7EO)PU6+[(U%"%#_=0CH!````%E97<-5B^Q14U:+=0A7A?9T9HL=
MA$!``/_3@S@`=%F*#HO&A,ET"X#Y/70&BD@!0.OQ*\:)1?S_TXLPBSZ%_W0W
M_W7\_W4(5_\50$!``(/$#(7`=0F+1?R`/`<]=`6#Q@3KV/_3*S"+10S!_@*)
M,(M%_(U$!P'K`C/`7UY;R<-5B^Q148M%#(`X/74#_T4,4U97_W4,Z,4F``"+
M70B)1?B-1?Q04^A:____BS6$0$``B_B#Q`R%_W0B5^B@)@``.T7X60^"RP``
M`(M-#(H!B`='083`=?;I/`$``/_6BP`S_S/).0AT!H/`!$?K]CD-1+1``'1`
MZ+LE``!0Z,TE``"+&%F-!+T(````4/_6_S#HH24``%#HLR4``%G_,/]3!(/$
M#(O8_]:)&/_6@S@`=57IL0```,<%1+1```$```#H<24``%#H@R4``(L868T$
MO0@```!0Z%LE``!0Z&TE``!9_S#_$XO8687;671YB\?!X`)0_];_,%/_%8!`
M0`"#Q`S_UHD8_]:+`(M="(-DN`0`B7W\B@.+^X3`=`H\/70&BD<!1^ORZ`HE
M``!0Z!PE``"+$(M%^"O[68E5"(U$!P)0Z.\D``!0Z`$E``!9_S"+10C_$%F+
M^%G_UHL`BTW\A?^)/(AU!8/(_^LN_]:+`(M-_(L$B(H+0X3)B`AT"(#Y/70#
M0.OOBU4,Q@`]0(H*B`A`0H3)=?8SP%]>6\G#BT0D!%:+\(O(B@"$P'07BQ40
ML$``BA(ZPG4#C7$!BD$!083`=?&+QE[#5HMT)`B%]G1O@#X`=&I6Z`,E``"-
M1##_68L-$+!``#O&=A:*$3@0=05(.\9W]SO&=@DX$'0#2.OU.\9U"8H`.@%T
M-5'K-T@[QG8&BA`Z$73U*\:-2`*!^0`$``!V!#/`7L-`4%:^/+!``%;_%7Q`
M0`"#Q`R+QE[#:)Q!0`#_%41`0`!97L-5B^R#["135E=J"%F^A$)``(U]W&AT
M0D``\Z5FI>@)`0``QP0D:$)``.C]````N[!!0`!3Z/(```"^7$)``%;HYP``
M`+]00D``5^C<````:$1"0`#HT@```&B@04``Z,@```!H.$)``.B^````:"Q"
M0`#HM````&@80D``Z*+\__^#Q"2%P'0)4%?H(OW__UE9:`1"0`#HB/S__X7`
M670-4&CX04``Z`;]__]966CH04``Z&S\__^%P%ET"U!3Z.[\__]96>M.:-1!
M0`#H4OS__X7`670$4%;KY&C,04``Z*TC``"_P$%``(U<!>A7Z)XC``!05U/_
M%7A`0`"#Q!2%P'425^B((P```\-05NB?_/__@\0,:+Q!0`!H=$)``.B-_/__
M65E?7EO)PU6+[%&-1?Q0_W4(Z/O[__]9A<!9=![_%81`0`"+`(M-_(T,B(M1
M!(U!!(72B1%TU(O(Z_#)PZ$8L$``@_C_=25H7$)``.BN^___A<!9=`^*`(3`
M=`D\,'0%:@%8ZP(SP*,8L$``PS/`PU6+[(/L(+C@0D``5XOX4(E%X,=%Y-A"
M0`#'1>C(0D``QT7LP$)``,=%\*Q"0`#'1?2H0D``B7WXZ,`B``"%P%D/AL0`
M``"-1>!35HE%_%?H._O__XOP687V#X2#````5NB8(@``A<!9='C_=0A6_Q6(
M0$``687`675SZ-0A``!0Z.8A``#_-12P0`"+..AK(@``5HO8Z&,B``#_=0@#
MV.A9(@``@\00C40#`E#HHB$``%#HM"$``%G_,/\75HOX_S44L$``_W4(:)1!
M0`!7_Q680$``5_]U^.A`^___@\0DZPO_=0A7Z#+[__]968-%_`2+1?R+.%>)
M??CH_B$``(7`60^'1O___UY;7\G#58OLN."```#H[2$``(-E_`!6N*A"0`!H
ML$%``,=%V(A#0`#'1=Q004``QT7@G$%``(E%Y,=%P/A!0`#'1<2`0T``QT7(
M>$-``,=%S'!#0`#'1=!L0T``B474QT7H9$-``,=%[%A#0`")1?#H$OK__XOP
M687V=!]6Z',A``"%P%ET%%;H:_[__U;_%41`0`!96>G0`P``4[X`!```5XEU
M^.BA(```4.BS(```BSA95NB2(```4.BD(```6?\P_Q=968U-^%%0_Q4`0$``
MZ!_^__^+V(7;B5WX=3V-?>B+-U;H"R$``(7`678@5NB2^?__A<!9=`M0_Q5$
M0$``68E%^(M=^(/'!(7;=-.%VW4)QT7X4$-``.M#@#L`B_-T/+\'`0``H61`
M0`"#.`%^#P^^!E=0_Q5H0$``65GK$8L-;$!```^^!HL)9HL$02/'A<!U`\8&
M7T:`/@!UR8U]P(LW5NB+(```A<!9=BQ6Z!+Y__^+\%F%]G065N@#&0``A<!9
M=`M6_Q5$0$``68E%_(/'!(-]_`!TQX-]_`"+-9A`0`!U>6A(0T``Z-;X__^+
MV%F%VW1HZ(X?``!0Z*`?``"+.%/H*B```%F#P`994.AU'P``4.B''P``6?\P
M_Q>+^%-H0$-``%?_UE?HDQ@``(/$&(7`=`6)??SK(NA('P``4.A:'P``BQA9
M5^@Y'P``4.A+'P``6?\P_U,(65F#??P`=2^-7=B+.U?HQ!\``(7`678?5^A)
M&```A<!9=`M7_Q5$0$``68E%_(/#!(-]_`!TU/]U^.B8'P``_W7\B_CHCA\`
M`+LX0T```_A3Z($?``!HJ$)```/XZ'4?``"-O`<`!```Z+\>``!0Z-$>``"+
M$(/$%(E5]%?HJQX``%#HO1X``%G_,(M%]/\0_W7XB_A3_S40L$``_W7\:"Q#
M0`!7_]97_Q5P0$``:,!"0`#HL??__U#_%41`0`"+70A0_S/HX?7__X/$-(E%
M"(7`=06+`XE%".C)^___A<`/A4X"``#H0AX``%#H3AX``(L8QP0D`(```/]U
M".@K'@``4.@W'@``6?\P_U,\@\0,B44(A<`/A!@"``#H#!X``%#H&!X``%F+
M&&H":O]J[O]U".CU'0``4.@!'@``6?\P_U,PZ.0=``!0Z/`=``"+&(/$&(V%
M('___VH&4/]U".C('0``4.C4'0``6?\P_U-$@\00@+T@?___``^%SP```("]
M(7___T,/A<(```"`O2)___]!#X6U````@+TC?___0P^%J````("])'___T@/
MA9L```"`O25___]%#X6.````Z&8=``!0Z'(=``!9BQAJ`FK_:L;_=0CH3QT`
M`%#H6QT``%G_,/]3,.@^'0``4.A*'0``BQB#Q!B-A2!___]J*5#_=0CH(AT`
M`%#H+AT``%G_,/]31(V%('___VBH0D``4/\U$+!``%=H'$-``%?_UH/$*%=H
ML$%``.BW]O__5^B4^O__@\0,B\=?6U[)PXV%(/___U#HG0$``.C,'```4.C8
M'```65F+&(V%('___V@`@```4/]U".BN'```4.BZ'```6?\P_U-$@\00A<!^
M)%"-A2!___]0C84@____4.B%`0``Z((<``!0Z(X<``"#Q!#KL^AR'```4.A^
M'```BQA9_W4(Z&$<``!0Z&T<``!9_S#_4Q"-A2#___]0C46L4.@B%```C46`
M@\00,]N)10@/MD0=K%!H%$-``/]U"/_6@T4(`H/$#$.#^Q1\XXU%@&BH0D``
M@&6H`%#_-1"P0`!7:!Q#0`!7_]:#Q!CI`?___X-E"`!7Z)D<``#'!"2\04``
M:%Q"0`")1?3HI?7__UE9:*A"0`#HSQL``%#HYQL``(L8Z,(;``!0Z-H;``#_
M,/]3:(/$#%#_-1"P0`!7:`1#0`!7_]97_Q5P0$``@\0<@_C_#X69_O___Q5T
M0$``@S@1#X6*_O__BT7T:*A"0`"`)#@`_T4(_W4(Z&L;``!0Z(,;``"+&.A>
M&P``4.AV&P``_S#_4VB#Q`Q0_S40L$``5VCP0D``5__65_\5<$!``(/$(.N:
MBT0D!#/)QP`!(T5GQT`$B:O-[\=`"/[<NIC'0`QV5#(0QT`0\.'2PXE(%(E(
M&(E(7,-5B^Q3BUT05HMU"%>+3A2-!-D[P7,#_T88B484B\/!Z!T!1AB+1ER%
MP'0T:D!?*_@[^WX"B_N+1EQ7_W4,C40&'%#HGQL```%]#`%^7(/$#"O?@WY<
M0'5+5NA*````68/[0'PLB_O![P:+Q_?8P>`&`]AJ0(U&'/]U#%#H9AL``(-%
M#$!6Z!X```"#Q!!/=>)3C48<_W4,4.A)&P``@\0,B5Y<7UY;7<-5B^R![%0!
M``"+10A35E>-4!R-M:S^___'10@0````BPJ#P@2+^8O9@><``/\`P>L0"_N+
MV8'C`/\``,'A$`O9P>\(P>,("_N)/H/&!/]-"'7-:D"-E;3^__]>BTHL,TH8
M,TKX,PJ#P@2+^0/)P>\?"_E.B7HT=>.+>`2+4`B+<`R+"(O?(]?WTR/>B_$+
MVHO1P>H;P>8%"]:+<!`#\P/6B[6L_O__C90RF7F"6HOWP>8>P>\""_>+^??7
M(W@(B77L(_&+V@O^B_+!ZQO!Y@4+WHNUL/[__P/W`]Z+<`R-O#.9>8):B_&+
MV8E]^,'F'L'K`@OSB]KWTR-=[(EU_"/R"]Z+M;3^__^)70B+W\'K&\'G!0O?
MBWT(`_>+^L'G'L'J`@/>BW`("_J+5?B-M#.9>8):BUWX]](C5?PCWXE]](O^
M"].+WL'O&\'C!0O[BYVX_O__`]H#^XM5[(V<%YEY@EJ+??B+UXE=",'B'L'O
M`@O7B_[WUR-]](E5^"/6"_J+T\'J&\'C!0O3BYV\_O__`]^+??P#TXV4.IEY
M@EJ+_L'G'L'N`@O^BW4(]]8C=?B)??`C?0B+VL'C!0OWB_K![QL+^XN=P/[_
M_P/>BW7T`_N-G#>9>8):BWT(B_>)7?S!YA[![P(+]XOZ]]<C??")=0@C\@O^
MB_/![AO!XP4+\XN=Q/[__P/?BWWX`_.-M#Z9>8):B_K!YQ[!Z@(+^HM5_/?2
M(U4(B7WL(WW\B][!XP4+UXO^P>\;"_N+G<C^__\#VHM5\`/[C9P7F7F"6HM]
M_(O7B5WXP>(>P>\""]>+_O?7(WWLB57\(]8+^HO3P>H;P>,%"].+G<S^__\#
MWXM]"`/3BUWXC90ZF7F"6HO^P><>P>X""_Z+=?CWUB-U_"/?B7WTB_H+\XO:
MP>\;P>,%"_N+G=#^__\#WHMU[`/[C9PWF7F"6HM]^(OWB5T(P>8>P>\""_>+
M^O?7(WWTB77X(_(+_HOSP>X;P>,%"_.+G=3^__\#WXM]_`/SC;0^F7F"6HOZ
MP><>P>H""_J+50CWTB-5^(E]\"-]"(O>P>,%"]>+_L'O&PO[BYW8_O__`]J+
M5?0#^XV<%YEY@EJ+?0B+UXE=_,'B'L'O`@O7B_[WUR-]\(E5""/6"_J+T\'J
M&\'C!0O3BYW<_O__`]^+??@#TXV4.IEY@EJ+_L'G'L'N`@O^BW7\]]8C=0B)
M?>PC??R+VL'C!0OWB_K![QL+^XN=X/[__P/>BW7P`_N-G#>9>8):BWW\B_>)
M7?C!YA[![P(+]XOZ]]<C?>R)=?PC\@O^B_/![AO!XP4+\XN=Y/[__P/?BWT(
M`_.+7?B-M#Z9>8):B_K!YQ[!Z@(+^HM5^/?2(U7\B7WT(]^+_@O3B][![QO!
MXP4+^XN=Z/[__P/:BU7L`_N-G!>9>8):BWWXB]>)70C!XA[![P(+UXO^]]<C
M??2)5?@CU@OZB]/!ZAO!XP4+TXN=[/[__P/?BWW\`].-E#J9>8):B_[!YQ[!
M[@(+_HMU"/?6(W7XB7WP(WT(B]K!XP4+]XOZP>\;"_N+G?#^__\#WHMU]`/[
MC9PWF7F"6HM]"(OWB5W\P>8>P>\""_>+^O?7(WWPB74((_(+_HOSP>X;P>,%
M"_.+G?3^__\#WXM]^`/SC;0^F7F"6HOZP><>P>H""_J+5?SWTB-5"(E]["-]
M_`O7B_[![QN+WL'C!0O[BYWX_O__`]J+5?`#^XV<%YEY@EJ+??R+UXE=^,'B
M'L'O`@O7B_O![QO!XP4+^XM=[(E5_#/:BY7\_O__,]X#UXO^`]J+50C!YQ[!
M[@(+_HV4$Z'KV6Z)??2+\HOZBYT`____P>X;P><%"_>+??@S??P#WHMU[#-]
M]`/[C9PWH>O9;HM]^(OWB5T(P>8>P>\""_>+^\'O&\'C!8EU^`O[BYT$____
M,_(S=?0#WXM]_`/SC;0^H>O9;HOZP><>P>H""_J+UHO>B7WPP>H;P>,%"].+
M7?@SWXN]"/___S-="`/ZBU7T`]^-G!.AZ]ENBWT(B5W\B]?!XA[![P(+UXO[
MP>\;P>,%"_N+7?")50@SVHN5#/___S/>`]>+_@/:BU7XP><>P>X"C903H>O9
M;@O^B_*+VL'N&\'C!0OSBUT(B7WL,]^+O1#___\S7?P#_HMU\`/?BWW\C9PS
MH>O9;HOWP>8>P>\""_>+^XE=^(EU_,'O&\'C!0O[BUWL,]Z+M13___\SV@/W
MB_H#WHMU",'G'L'J`@OZC;0SH>O9;HE]](O6B_Z+G1C____!ZAO!YP4+UXM]
M^#-]_`/:BU7L,WWT`_N-G!>AZ]ENBWWXB]>)70C!XA[![P(+UXE5^(O[,]8S
M5?3![QO!XP4+^XN='/___P/?BWW\`].-E#JAZ]ENB_[!YQ[![@(+_HORB]J)
M??#![AO!XP4+\XM=^#/?B[T@____,UT(`_Z+=?0#WXM]"(V<,Z'KV6Z+]\'F
M'L'O`@OWB_N)7?R)=0C![QO!XP4+^XM=\#/>B[4D____,]H#]P/>BW7XB_K!
MYQ[!Z@*-M#.AZ]EN"_J+UHO>P>H;P>,%"].+70B)?>PSWXN]*/___S-=_`/Z
MBU7P`]^+??R-G!.AZ]ENB]?!XA[![P(+UXO[B5WXB57\P>\;P>,%"_N+7>PS
MVHN5+/___S/>`]>+_@/:BU4(P><>P>X""_Z-E!.AZ]ENB7WTB_*+^HN=,/__
M_\'N&\'G!0OWBWWX,WW\`]Z+=>PS??0#^XV<-Z'KV6Z+??B+]XE=",'F'L'O
M`@OWB_O![QO!XP6)=?@+^XN=-/___S/R,W7T`]^+??P#\XVT/J'KV6Z+^L'G
M'L'J`@OZB]:+WHE]\,'J&\'C!0O3BUWX,]^+O3C___\S70@#^HM5]`/?BWT(
MC9P3H>O9;HO7P>(>P>\""]>+^XE=_(E5",'O&\'C!0O[BUWP,]J+E3S___\S
MW@/7`]J+5?B-O!.AZ]ENB];!XA[![@(+UHOWB]_![AO!XP4+\XM="(E5[#/:
MBY5`____,UW\`]:+=?P#VHM5\(V<$Z'KV6Z+UL'B'L'N`@O6B_.)7?B)5?S!
M[AO!XP4+\XM=[#/:BY5$____,]\#UHOW`]J+50C!YA[![P(+]XV4$Z'KV6Z)
M=?2+\HOZBYU(____P>X;P><%"_>+??@S??P#WHMU[#-]]`/[C;0WH>O9;HM]
M^(EU"(OWP>8>P>\""_>+^@M]](M="(EU^"/^B_(C=?3!XP4+_HMU",'N&POS
MBYU,____`]^+??P#\XVT/MR\&X^+^L'G'L'J`@OZB]>)??`+50@C5?@C?0B+
MW@O7B_[![QO!XP4+^XN=4/___P/:BU7T`_N-G!?<O!N/BWT(B]>)7?S!XA[!
M[P(+UXOZB54("_XCUB-]\`OZB]/!ZAO!XP4+TXN=5/___P/?BWWX`].-E#K<
MO!N/B_[!YQ[![@(+_HO:B_>)?>P+=?PC??S!XP4C=0@+]XOZP>\;"_N+G5C_
M__\#WHMU\`/[C9PWW+P;CXM]_(OWB5WXP>8>P>\""_>+_HEU_`OZ(_(C?>P+
M_HOSP>X;P>,%"_.+G5S___\#WXM]"`/SC;0^W+P;CXOZP><>P>H""_J+5?R)
M??2+7?P+UR-5^"/?B_X+TXO>P>\;P>,%"_N+G6#___\#VHM5[`/[C907W+P;
MCXM]^(E5"(O7P>(>P>\""]>+_@M]](M="(E5^"/ZB]8C5?3!XP4+^HM5",'J
M&PO3BYUD____`]^+??P#TXV4.MR\&X^+_L'G'L'N`@O^B]J+]XE]\`MU""-]
M",'C!2-U^`OWB_K![QL+^XN=:/___P/>BW7T`_N-G#?<O!N/BWT(B_>)7?S!
MYA[![P(+]XO^B74("_HC\B-]\`O^B_/![AO!XP4+\XN=;/___P/?BWWX`_.-
MM#[<O!N/B_K!YQ[!Z@(+^HO>B]>)?>P+5?PC??S!XP4C50@+UXO^P>\;"_N+
MG7#___\#VHM5\`/[C9P7W+P;CXM]_(O7B5WXP>(>P>\""]>+^HE5_`O^(]8C
M?>P+^HO3P>H;P>,%"].+G73___\#WXM]"`/3BUW\C90ZW+P;CXO^P><>P>X"
M"_Z+=?P+]R/?(W7XB7WTB_H+\XO:P>\;P>,%"_N+G7C___\#WHMU[`/[C;0W
MW+P;CXM]^(EU"(OWP>8>P>\""_>+^@M]](M="(EU^"/^B_(C=?3!XP4+_HMU
M",'N&POSBYU\____`]\#\XM]_(VT/MR\&X^+^L'G'L'J`@OZB]Z+UXE]\`M5
M""-]",'C!2-5^`O7B_[![QL+^XM=@`/:BU7T`_N-G!?<O!N/BWT(B]>)7?S!
MXA[![P(+UXOZB54("_XCUB-]\`OZB]/!ZAO!XP4+TXM=A`/?BWWX`].-E#K<
MO!N/B_[!YQ[![@(+_HO:B_>)?>P+=?PC??S!XP4C=0@+]XOZP>\;"_N+78@#
MWHMU\`/[C9PWW+P;CXM]_(OWB5WXP>8>P>\""_>+_HEU_`OZ(_(C?>P+_HOS
MP>X;P>,%"_.+78P#WXM]"`/SBUW\C;0^W+P;CXOZP><>P>H""_J+5?P+UR/?
M(U7XB7WTB_X+TXO>P>\;P>,%"_N+79`#VHM5[`/[C907W+P;CXM]^(E5"(O7
MP>(>P>\""]>+_@M]](M="(E5^"/ZB]8C5?3!XP4+^HM5",'J&PO3BUV4`]^+
M??P#TXV4.MR\&X^+_L'G'L'N`@O^B]J+]XE]\`MU""-]",'C!2-U^`OWB_K!
M[QL+^XM=F`/>BW7T`_N-G#?<O!N/BWT(B_>)7?S!YA[![P(+]XO[P>\;P>,%
M"_N+7?`SWHEU"#/:BW6<`_>+^@/>BW7XP><>P>H"C;0SUL%BR@OZB]:+WL'J
M&\'C!0O3BUT(,]^)?>R+?:`S7?P#^HM5\`/?BWW\C9P3UL%BRHO7P>(>P>\"
M"]>+^XE=^(E5_,'O&\'C!0O[BUWL,]J+5:0SW@/7B_X#VHM5",'G'L'N`@O^
MC903UL%BRHE]](ORB_J+7:C![AO!YP4+]XM]^#-]_`/>BW7L,WWT`_N-G#?6
MP6+*BWWXB_>)70C!YA[![P(+]XO[P>\;P>,%B77X"_N+7:PS\C-U]`/?BWW\
M`_.-M#[6P6+*B_K!YQ[!Z@(+^HO6B]Z)??#!ZAO!XP4+TXM=^#/?BWVP,UT(
M`_J+5?0#WXM]"(V<$];!8LJ+U\'B'L'O`@O7B_N)7?R)50C![QO!XP4+^XM=
M\#/:BU6T,]X#UP/:BU7XB_[!YQ[![@*-E!/6P6+*"_Z+\HO:P>X;P>,%"_.+
M70B)?>PSWXM]N#-=_`/^BW7P`]^+??R-G#/6P6+*B_?!YA[![P(+]XO[B5WX
MB77\P>\;P>,%"_N+7>PSWHMUO#/:`_>+^@/>BW4(P><>P>H""_J-M#/6P6+*
MB7WTB]:+_L'J&\'G!0O7BWWXBUW`,WW\`]J+5>PS??0#^XV<%];!8LJ+??B+
MUXE=",'B'L'O`@O7B_O![QO!XP6)5?@+^XM=Q#/6,U7T`]^+??P#TXV4.M;!
M8LJ+_L'G'L'N`@O^B_*+VHE]\,'N&\'C!0OSBUWX,]^+?<@S70@#_HMU]`/?
MBWT(C9PSUL%BRHOWP>8>P>\""_>+^XE=_(EU",'O&\'C!0O[BUWP,]Z+=<PS
MV@/W`]Z+=?B+^L'G'L'J`HVT,];!8LH+^HO6B][!ZAO!XP4+TXM="(E][#/?
MBWW0,UW\`_J+5?`#WXV<$];!8LJ+??R)7?B+U\'B'L'O`@O7B_O![QO!XP4+
M^XM=[(E5_#/:BU74,]X#UXO^`]J+50C!YQ[![@(+_HV4$];!8LJ)??2+\HOZ
MBUW8P>X;P><%"_>+??@S??P#WHMU[#-]]`/[C9PWUL%BRHM]^(OWB5T(P>8>
MP>\""_>+^\'O&\'C!8EU^`O[BUW<,_(S=?0#WXM]_`/SC;0^UL%BRHOZP><>
MP>H""_J+UHO>B7WPP>H;P>,%"].+7?@SWXM]X#-="`/ZBU7T`]^+?0B-G!/6
MP6+*B]?!XA[![P(+UXE=_(E5"(O[P>\;P>,%"_N+7?`SVHM5Y#/>`]<#VHM5
M^(O^P><>P>X"C903UL%BRHM="`O^B_*)5?0SW\'N&\'B!0ORBU7\,]H#S@/9
MBTWP`UWHBW7TC8P+UL%BRHD(BT@$`\Z)2`2+RL'A'L'J`@O*BU4(`T@(B4@(
MBT@,`\]?B4@,BT@0`\I>B4@06\G#58OL4U:+=0R+1AB+7A2)10R+P\'H`X/@
M/\9$,!R`0(/X.'XJ:D!9*\B-1#`<46H`4.C7"```5NB-[?__:CB-1AQJ`%#H
MQ`@``(/$'.L5:CA9*\B-1#`<46H`4.BM"```@\0,BT4,5HO(B$97P>D8B$Y4
MB\C!Z1"(3E6+R(O#_W4(P>@8B$98B\/!Z!"(1EF+P\'I",'H"(A.5HA&6HA>
M6^@&````65E>6UW#5HMT)`Q6Z!/M__^+1"0,68L.P>D8B`B+#L'I$(A(`8L.
MP>D(B$@"B@Z(2`.+5@2-3@3!ZAB(4`2+$<'J$(A0!8L1P>H(B%`&B@F(2`>+
M5@B-3@C!ZAB(4`B+$<'J$(A0"8L1P>H(B%`*B@F(2`N+5@R-3@S!ZAB(4`R+
M$<'J$(A0#8L1P>H(B%`.B@F(2`^+5A"-3A!>P>H8B%`0BQ'!ZA"(4!&+$<'J
M"(A0$HH)B$@3PU;HP`8``%#HS`8``(LPZ+,&``!0Z+D&``!965#_="0,Z*$&
M``!0Z*T&``!9_S#_5E"#Q`R%P'5*Z(D&``!0Z(\&``!FBT`&668E`/!F/0!`
M=3#H;P8``%#H>P8``(LP66H"_W0D#.A;!@``4.AG!@``6?\P_Q:#Q`R%P'4%
M:@%87L,SP%[#5HMT)`A75NC'X?__4.B7X?__68OX6>B?X___A<!T*(7V="16
MZ,$&``"%P%ET&6@X0T``5_\5B$!``%D[QUEU!U;H!````%E?7L.![!P!``!3
MBYPD)`$``%97A=L/A"8!``!3Z((&``"%P%D/A!<!``!3Z',&``"+\('&`@$`
M`.B\!0``4.C.!0``BSA965;HK`4``%#HO@4``%G_,/\7B_!3:*1#0`!6_Q68
M0$``C40D)%!6_Q5(0$``@\0<@_C_B40D#`^$O@```%6++4Q`0`#K!XN<)#`!
M``"+/8A`0`"-1"0H:%!!0`!0_]=9A<!9C40D*%!U$E-HG$-``%;_%9A`0`"#
MQ!#K#VB80T``5O\5F$!``(/$#+N40T``4U;_UXOX687_670>4U?HM`4``%F%
MP%ET'VB00T``5^BC!0``687`670.]D0D%!!T1%;H]O[__UF-1"044/]T)!3_
M%5!`0`!9A<!9#X1E_____W0D$/\55$!``/^T)#0!``#_%:1`0`!965U?7EN!
MQ!P!``##C40D*%#_%1!`0`"+^#/;5O_5A<!9=*R+PT.#^`I]I(7_=.Q7_Q4,
M0$``Z^-1@V0D``!35E?H=`0``%#HR`0``&H!6X@8QP0D=$)``.B9W?__A<!9
M=`N`.#%U!H!X`0!T!>AAX/__:@I3:!!$0`#H.P0``%#HB00``(/$$(7`#X2B
M````BP`Y'3RT0`!5B_.+0""+>!!^8[T```0`C4;_:@!05^@&!```4.A.!```
M@\00A<!T18L`BT@((\T[S74&BP"+`.L3:@)J`%#HW@,``%#H(`0``(/$$%"A
M0+1``/\TL.AK!```687`674-_T0D$$8[-3RT0`!\HJ$\M$``78U(_SE,)`QU
M'3O#B_-^%U?HF0,``%#HU0,``$99.S4\M$``67SI:@13:`Q$0`#H>P,``%#H
MR0,``(OP@\00A?9T-8L&:`!$0`"+0"#_,.A;`P``4.B1`P``BP:#Q`R+0""+
M`/9`"4!T#E#H/P,``%#H;P,``%E9:@13:/Q#0`#H*@,``%#H>`,``(OP@\00
MA?9T<FB@04``Z$W<__^%P%ET`U#K2^BNX/__B_B%_W0YBP97BT`@_S#H\0(`
M`%#H)P,``.CF`@``4.CX`@``BS"#Q!!7Z-4"``!0Z.<"``!9_S#_5@A96>L<
MH4"T0`#_,(L&BT`@_S#HL@(``%#HZ`(``(/$#.BD`@``4.CX`@``@"``Z)8"
M``!0Z,`"``"#(`!HL$%``.B_V___@\0,HSBP0`"%P'41_S5`M$``Z";A__]9
MHSBP0`#H80(``%#HA0(``(LPQP0D[0$``/\U.+!``.A'`@``4.AK`@``6?\P
M_Q:#Q`R%P%]>6W0E@_@1=""#^/]T&U"A0+1``/\U.+!``/\P:*Q#0`#H-`(`
M`(/$$%G#58OL45%6C44,5U"-10A0_Q6P0$``,_]7Z(0"``"#Q`R`.`!U2^AQ
M`@``.\>C-+!``'4CZ-,!``!0Z.L!``"+,%EJ`>C#`0``4.C;`0``6?\P_U8(
M65G_-32P0`#H-`(``.BE`0``4.@C`@``68DX6>B6`0``4.@.`@``@`@"Z(@!
M``!0Z``"``"`"`&+10B#P`6)??R)1?A9WVWX6=P=.$1``-_@GG8+:"!$0`#H
M?0$``%F+10B-!(44````4.C``0``6:-`M$``BTT,:@&+"8D(H4"T0`#'0`0<
M1$``H4"T0`#'0`A81$``H4"T0`#'!3RT0``#````QT`,&$1``/\%/+1``%@Y
M10A^'HL-/+1``(M5#(LU0+1```/(BQ2"0(E4COP[10A\XJ$\M$``BTT(`\&+
M#4"T0`!7B7R!_*$\M$``BTT(_S5`M$``C40(_U!H@CA``/\U-+!``.@;`0``
MB_"#Q!0[]W4._S4TL$``Z`$!``!9B_#_-32P0`#H[0```,<$)&A"0`#HM]G_
M_X7`674DH3BP0``[QW44:+!!0`#HG]G__SO'6:,XL$``=`=0Z!/Z__]9_S4T
ML$``Z*<```!9_Q7<0$``B\9?7LG#Z#4```!0Z'/7__]9N*A"0`!J`%!0:#HT
M0`!H0$1``.@6````4.BL````@\08P_\E)$%``/\E($%``/\E'$%``/\E&$%`
M`/\E%$%``/\E$$%``/\E#$%``/\E"$%``/\E!$%``/\E`$%``/\E_$!``/\E
M^$!``/\E]$!``/\E\$!``/\E[$!``/\EZ$!``/\EY$!``/\EX$!``/\EV$!`
M`/\EU$!``/\ET$!``/\ES$!``/\ER$!``/\EQ$!``/\EP$!``/\EO$!``/\E
MN$!``/\EM$!``/\EK$!``,S,_R640$``_R6,0$``S,S,S%$]`!```(U,)`AR
M%('I`!```"T`$```A0$]`!```'/L*\B+Q(4!B^&+"(M`!%##S/\E8$!``/\E
M7$!``,S,S,Q5B^QJ_VC`FT``:.`Z0`!DH0````!09(DE`````(/L(%-65XEE
MZ(-E_`!J`?\56$!``%F##5BT0`#_@PU<M$``__\5&$!``(L-5+1``(D(_Q4<
M0$``BPU0M$``B0BA($!``(L`HV"T0`#HP````(,],+!```!U#&AF%D``_Q4D
M0$``6>B4````:`RP0`!H"+!``.A_````H4RT0`")1=B-1=A0_S5(M$``C47@
M4(U%U%"-1>10_Q4L0$``:`2P0`!H`+!``.A,````_Q4P0$``BTW@B0C_=>#_
M==3_=>3H'OS__X/$,(E%W%#_%31`0`"+1>R+"(L)B4W04%'H#P```%E9PXME
MZ/]UT/\5/$!``/\E.$!``/\E*$!``&@```,`:````0#H"P```%E9P\/,_R6<
M0$``_R6@0$``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````."?````````FI\``+"?``"^GP```````(BA``!XH0``:*$``%2A``!(
MH0``.*$``"BA```@H0``$J$```JA``#RH```Z*```-J@``#0H```Q*```+:@
M``"6H0``HJ```)B@``"(H```?*```'*@``!HH```7J```%2@``!*H```0*``
M`#"@```FH```'*```!*@```(H```_I\``*BA``"\H0``K*````````!ZGP``
M:)\``%*?``!$GP``,I\``!*?``#ZG@``Y)X``-:>``#*G@``NIX``*Z>``"<
MG@``B)X``':>``!FG@``4IX``$*>```RG@``))X``!">````G@``Z)T``-:=
M``#&G0``MIT``**=``"0G0``?)T``&Z=``!<G0``````````````````2?.1
M2``````"````20``````````X```.P```%P```!7:6XS,D-/4D4Z.F)O;W1S
M=')A<`````!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`<&5R;'AS:2YC
M````)7,E<R5S```N````4$%27U!23T=.04U%`````%!!4E]414U0`````#$`
M``!005)?0TQ%04X]``!#3$5!3@```%!!4E]'3$]"04Q?0TQ%04X`````4$%2
M7T=,3T)!3%]414U0`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$U01$E2````
M4$%27T=,3T)!3%]$14)51P````!005)?05)'5E\P``!005)?05)'0P````!0
M05)?0T%#2$4```!005)?1$5"54<```!005)?0TQ%04X```!005)?4U!!5TY%
M1`!005)?24Y)5$E!3$E:140`7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@
M("`@("```````````$193$1?3$E"4D%265]0051(````4$%42`````!,24)2
M05)97U!!5$@`````3$E"4$%42`!,1%],24)205)97U!!5$@`)7,E<W1E;7`M
M)74M)74E<P`````E<R5S=&5M<"TE=25S````)3`R>``````E<R5S8V%C:&4M
M)7,E<P``)7,E<R5S)7,`````<&%R+0`````E<UQT96UP`%=I;D1I<@``4UE3
M5$5-``!54T523D%-10````!54T52`````%1-4`!414U0`````%1%35!$25(`
M5$U01$E2``!#.EQ414U0`%PN+@!<+@``)7,``"5S7"5S````)7-<*BXJ```E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@```#````!P97)L+F5X
M90`````8````05)'5@`````M+0``+64``'!A;FEC.B!M96UO<GD@=W)A<```
M````````@/___\]!26YT97)N86QS.CI005(Z.D)/3U0`````(R$O=7-R+V)I
M;B]P97)L"@IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB
M)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@
M;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E
M('-T<FEC=#L*"B-L:6YE(#$U.0H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE
M+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@
M(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA
M;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H
M<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z
M.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN
M:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$
M;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E
M('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A
M<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@
M=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I
M8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI
M;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B
M;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD
M"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@
M;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG
M="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P
M<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T
M:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*
M("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@
M("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@
M("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)
M3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B
M:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F
M("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE
M;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD
M>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@
M("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@
M;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@
M)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D[
M"B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T
M;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL
M96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@
M("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[
M4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'
M5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!
M4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@
M>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD
M7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.
M5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O
M;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^
M("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G
M)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T
M96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN
M9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P
M;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@
M("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO
M;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@
M("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@
M+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S
M("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#([
M"B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U
M;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*
M("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@
M("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@
M;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@
M>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN
M86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D
M9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE
M(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@
M("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@
M("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@
M("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\
M:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I
M(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U
M="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@
M("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E
M("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@
M("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL
M:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@
M("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@
M("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E
M>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*
M("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D
M:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@
M('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@
M("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI
M<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^
M("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@
M("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@
M("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@
M?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@
M(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?
M;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L
M95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME
M>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@
M("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D
M=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE
M9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN
M;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[
M8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@
M("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I
M;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@
M("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I
M;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO
M<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F
M:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H
M)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@
M("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M
M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@
M8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B
M:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q
M=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@
M(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG
M(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&
M:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?
M7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD
M9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@
M("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F
M:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3
M:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@
M("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@
M('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P
M,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@
M?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*)'%U
M:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PH*(R!$;VXG="!S=V%L
M;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U
M="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?
M8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@
M(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@
M("!S("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*
M"B`@("!M>2!`861D7W1O7VEN8SL*("`@('=H:6QE("A`05)'5BD@>PH@("`@
M("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["@H@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@
M<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF
M("@D,2!E<2`G32<I('L*("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@
M("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@
M("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L
M<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@)&]U="`]("0R.PH@("`@
M("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@
M("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D
M,2!E<2`G0B<I('L*("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@
M("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@
M("1Q=6EE="`](#$["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G
M3"<I('L*("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("!]"B`@("`@
M("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`D8V%C:&5?;F%M
M92`]("0R.PH@("`@("`@('T*"B`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@
M("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@
M("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@(&EN:71?
M:6YC*"D["B`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@
M("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@
M("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*
M("`@("`@("`@("`@97AI=#L*("`@("`@("!]"B`@("!]"@H@("`@=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0H*(R!86%@@+2T@861D("TM<&%R+61E
M8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L
M:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#
M>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@
M("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI
M=F4Z.EII<#L*("`@('T*"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@
M("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@
M)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@
M("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*
M"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@
M("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE
M=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H
M6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E
M;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<
M-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L
M("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E
M*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U
M;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T
M95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\
M($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*
M("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F
M:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O
M<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R
M(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*
M("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@
M("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@
M/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M
M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@
M("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@
M("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA
M9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T
M*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R
M*3L*("`@("0O(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N
M9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R
M97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@<F5Q
M=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@
M("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@
M9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"![
M"B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@
M("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@
M("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"B`@("`@("`@?2!`24Y#.PH*("`@("`@("!I9B`H)$-O;F9I9WM?9&5L:6U]
M(&5Q("=<7"<I('L@<WM<7'U[+WUG(&9O<B!`:6YC('T*"B`@("`@("`@;7D@
M)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD("1F:6QE<WLD,7TK*R!F
M;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@
M)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[
M;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A
M8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE
M+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I
M('L*("`@("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D
M7SL*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C
M72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I
M(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R
M+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F
M+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B
M)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D
M;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D
M969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@
M("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1
M)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@
M("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M
M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@
M("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@
M("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E
M;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS92!["B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@
M;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@
M("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\
M1DE,13X["B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@
M("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O
M;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!
M4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*
M"B`@("`@("`@("`@("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC:R!U
M<"!A=71O+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@)&-O
M;G1E;G0@/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E=')Y
M.R\*("`@("`@("`@("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H(EA3
M3&]A9&5R+G!M(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H
M<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I
M;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@
M;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS
M<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI:
M:7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@
M("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I
M.PH@("`@("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@
M;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA
M;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C
M:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@
M("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$
M:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@
M("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z
M.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN
M($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E
M<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H
M)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U
M="(I*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@
M("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C
M;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D
M8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64[
M"B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H
M("1C86-H95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@
M("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C
M:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H
M+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H
M;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*
M"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*
M>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F
M:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A
M;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@
M4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@
M("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@
M:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I
M;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@
M;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@
M9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`[
M"B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM0
M05)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@
M<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M
M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^
M9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M
M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S
M:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S
M:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@
M("`@("`@)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A
M8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL
M93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M
M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@
M)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@
M("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L
M<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D
M;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@
M("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@
M("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/
M(&5Q(")H<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@
M(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U
M;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O
M9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z
M("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R
M8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM
M3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#
M<F5A=&50871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H
M+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G
M7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@
M("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[
M(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U
M;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF
M("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U
M:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U
M:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E
M('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE
M879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E
M($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL
M93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@
M6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z
M.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O
M;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R
M97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I
M<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U
M:7)E(%=I;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@
M?3L*("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!]
M.PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@
M;7EL9'(O;6MT;7!D:7(N8PIS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PH@("`@("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@
M('T*"B`@("!F;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[
M)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I
M*2P*("`@("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@
M("`@(&YE>'0@=6YL97-S("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*
M("`@("`@("`C(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E
M=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT[
M"@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2![
M"B`@("`@("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@
M("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@
M("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I
M<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@
M("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM0
M05)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY
M72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE
M*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@
M<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F
M(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU
M."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*
M("`@("`@("`@("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@
M("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE
M=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@
M("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N
M9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L
M('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@
M("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO
M;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F
M:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T
M>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@
M("`@("`@("`@("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]
M"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@
M;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@
M("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY
M("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*
M"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M
M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I
M;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E
M9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O
M<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D
M92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*<W5B(%]S
M971?<')O9VYA;64@>PH@("`@:68@*"1%3E9[4$%27U!23T=.04U%?2!A;F0@
M)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G
M;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R
M*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R
M(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@
M("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@
M("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I
M9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@
M("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L
M:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@
M("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E
M<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG
M>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@
M("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]
M"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B
M+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@
M+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE
M9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@
M("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I
M9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?
M24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!]
M(&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@
M("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!
M0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!4
M14U0($-,14%.($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@
M/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?
M1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%
M3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6
M>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%
M04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL
M(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!
M3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@
M?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@
M*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]
M"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U
M8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@
M("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA
M:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN
M.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R
M.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N
M)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE
M(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O
M("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@
M/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D
M.CI?7T524D]2.PH*,3L*"B-L:6YE(#DY,PH*7U]%3D1?7PH`````<&%R+G!L
M``#_____H#I``+0Z0`#<G`````````````".GP``K$```#B<````````````
M`-*?```(0```,)P`````````````\)\```!```!(G`````````````#^H```
M&$``````````````````````````````X)\```````":GP``L)\``+Z?````
M````B*$``'BA``!HH0``5*$``$BA```XH0``**$``""A```2H0``"J$``/*@
M``#HH```VJ```-"@``#$H```MJ```):A``"BH```F*```(B@``!\H```<J``
M`&B@``!>H```5*```$J@``!`H```,*```":@```<H```$J````B@``#^GP``
MJ*$``+RA``"LH````````'J?``!HGP``4I\``$2?```RGP``$I\``/J>``#D
MG@``UIX``,J>``"ZG@``KIX``)R>``"(G@``=IX``&:>``!2G@``0IX``#*>
M```DG@``$)X```">``#HG0``UIT``,:=``"VG0``HIT``)"=``!\G0``;IT`
M`%R=````````'05B;V]T7U=I;C,R0T]210``X0-097)L7VYE=UA3`````U!E
M<FQ?9V5T7V-O;G1E>'0``!P%8F]O=%]$>6YA3&]A9&5R`&<"4&5R;%]4<W1A
M=&)U9E]P='(`MP!097)L7TE,24]?<'1R`+H`4&5R;%])365M7W!T<@"^`%!E
M<FQ?25!R;V-?<'1R``#&`E!E<FQ?8W)O86M?;F]C;VYT97AT``"U`%!E<FQ?
M241I<E]P='(`U@!097)L7TEC;VUP8W9?<'1R``"4`U!E<FQ?;6=?<V5T`+D$
M4&5R;%]S=E]S971P=@""`E!E<FQ?879?<VAI9G0`:@1097)L7W-V7S)P=E]F
M;&%G<P![`E!E<FQ?879?9F5T8V@`(@-097)L7V=V7V9E=&-H<'8`:P)097)L
M7U1T86EN=&5D7W!T<@`9!5!E<FQ?=VEN,S)?=&5R;0`G!7!E<FQ?9G)E90`F
M!7!E<FQ?9&5S=')U8W0`*@5P97)L7W)U;@``*05P97)L7W!A<G-E```?!%!E
M<FQ?<V%F97-Y<VUA;&QO8P``]P!097)L7TEE>&ET7V9L86=S7W!T<@``8@%0
M97)L7TEP97)L7V1E<W1R=6-T7VQE=F5L7W!T<@`E!7!E<FQ?8V]N<W1R=6-T
M```?!7!E<FQ?86QL;V,``)@`4&5R;%]'9&]?=6YD=6UP7W!T<@`8!5!E<FQ?
M=VEN,S)?:6YI=`#B`U!E<FQ?;F5W6%-?9FQA9W,``'!E<FPU."YD;&P``"0!
M1V5T36]D=6QE1FEL94YA;65!``"T`$9R965,:6)R87)Y`"8!1V5T36]D=6QE
M2&%N9&QE00``2T523D5,,S(N9&QL``#7`$=E=%5S97).86UE00``041605!)
M,S(N9&QL``"R`G-P<FEN=&8`N`)S=')C;7```,<"<W1R=&]K``"^`G-T<FQE
M;@``Q0)S=')S='(``&T`7U]P7U]E;G9I<F]N``"8`FUE;6UO=F4`P0)S=')N
M8W!Y`,`"<W1R;F-M<`#(`%]E<G)N;P``@@%?;6MD:7(``(X!7W!C='EP90`5
M`5]I<V-T>7!E``!A`%]?;6)?8W5R7VUA>```EP)M96UC<'D``)D";65M<V5T
M``"9`5]R;61I<@``WP!?9FEN9&-L;W-E``#B`%]F:6YD;F5X=`#=`5]U;FQI
M;FL`X`!?9FEN9&9I<G-T``"_`5]S=')D=7``Q0%?<W1R;FEC;7``35-60U)4
M+F1L;```TP!?97AI=`!(`%]88W!T1FEL=&5R`$D"97AI=```9`!?7W!?7U]I
M;FET96YV`%@`7U]G971M86EN87)G<P`/`5]I;FET=&5R;0"#`%]?<V5T=7-E
M<FUA=&AE<G(``)T`7V%D:G5S=%]F9&EV``!J`%]?<%]?8V]M;6]D90``;P!?
M7W!?7V9M;V1E``"!`%]?<V5T7V%P<%]T>7!E``#*`%]E>&-E<'1?:&%N9&QE
M<C,``+<`7V-O;G1R;VQF<```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````4$%``$Q!0`#_____N)M``%Q7
M```````````````````!````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````#``,````H``"`#@```$@``(`0
M````8```@````````````````````@`!````>```@`(```"0``"`````````
M```````````!`&4```"H``"````````````````````!``$```#```"`````
M```````````````!``````#8```````````````````````!``````#H````
M```````````````````!``````#X```````````````````````!```````(
M`0``F,,``&@%``````````````#)``"H"`````````````"HT0``(@``````
M````````(,$``'0"````````````````````````=`(T````5@!3`%\`5@!%
M`%(`4P!)`$\`3@!?`$D`3@!&`$\``````+T$[_X```$`````````````````
M`````#\````!````!``$``$```````````````````#4`0```0!3`'0`<@!I
M`&X`9P!&`&D`;`!E`$D`;@!F`&\```"P`0```0`P`#0`,``P`#``-`!B`#``
M```8`````0!#`&\`;0!M`&4`;@!T`',````@`````0!#`&\`;0!P`&$`;@!Y
M`$X`80!M`&4``````"@````!`$8`:0!L`&4`1`!E`',`8P!R`&D`<`!T`&D`
M;P!N```````@`````0!&`&D`;`!E`%8`90!R`',`:0!O`&X``````"`````!
M`$D`;@!T`&4`<@!N`&$`;`!.`&$`;0!E````)`````$`3`!E`&<`80!L`$,`
M;P!P`'D`<@!I`&<`:`!T````*`````$`3`!E`&<`80!L`%0`<@!A`&0`90!M
M`&$`<@!K`',``````"@````!`$\`<@!I`&<`:0!N`&$`;`!&`&D`;`!E`&X`
M80!M`&4````@`````0!0`'(`:0!V`&$`=`!E`$(`=0!I`&P`9````"`````!
M`%``<@!O`&0`=0!C`'0`3@!A`&T`90``````)`````$`4`!R`&\`9`!U`&,`
M=`!6`&4`<@!S`&D`;P!N````(`````$`4P!P`&4`8P!I`&$`;`!"`'4`:0!L
M`&0```!$`````0!6`&$`<@!&`&D`;`!E`$D`;@!F`&\``````"0`!````%0`
M<@!A`&X`<P!L`&$`=`!I`&\`;@````````2P!``````H````$````"`````!
M``@````````!```````````````!`````0``!@8&``0$!``"`@(``````$)"
M0@"=G9T`;FYN`(&!@0"QL;$`____`'-S<P"?GY\`6%A8`+*RL@#]_?T`:VMK
M`/S\_`#7U]<`%A86`-K:V@"6EI8`CHZ.`$9&1@#+R\L`"PL+`*"@H`#^_OX`
MR<G)`,'!P0`#`P,`$1$1`).3DP"SL[,`[N[N`/3T]`#CX^,`Y>7E`**BH@"Z
MNKH`KZ^O``<'!P!Q<7$`M;6U`/7U]0")B8D`BHJ*`#0T-`#HZ.@`-34U`%I:
M6@"WM[<`V-C8`-#0T``='1T`#`P,`(^/CP"^OKX`;6UM``D)"0";FYL`+R\O
M`,W-S0#9V=D`&1D9`$U-30!$1$0`4%!0`#P\/`!D9&0`PL+"`#(R,@`("`@`
M#0T-``\/#P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````%!04%!04%!04%!04%!00$!`35`(P5!,4-!041%
M+@$!`0$!`0$%`3P7%P$!$P$!`0$!`0$!%0$!)A4!`0\!`0$!`0$!`1,!$0$%
M-0$F`0$!`0$!`0$B$A`Q#P4!(`$!`0$!`0$!$`H@(A45+B$N`0$!`0$?("$0
M(A`C(R4F)P$!`0$E$!`0$!`0$!`0%T4!`0%!$!`0$!`0$!`0$!`7`0$!#Q`0
M%1`0$!`0$!`0`0$!`1(0$!,?$!`0$!`0!P$!`0$@$!`0`0\0$!`0$0$!`0$!
M!R`0"@$!!1`0$#$!`0$!`0$!`0$!`0%!!0\!`0$!`0$!`0$!`0$!`0$!`0$!
M`0&``0``P`$``.`#``#P`P``\`,``/`#``#@`P``P`$``(`!``"``0``@`,`
M`(`#````!P````<``(X/``#_'P``*````"````!``````0`(````````!```
M`````````````0````$````````!`0$``@("``,#`P`$!`0`!04%``8&!@`'
M!P<`"`@(``D)"0`*"@H`"PL+``P,#``-#0T`#@X.``\/#P`0$!``$1$1`!(2
M$@`3$Q,`%!04`!45%0`6%A8`%Q<7`!@8&``9&1D`&AH:`!L;&P`<'!P`'1T=
M`!X>'@`?'Q\`("`@`"$A(0`B(B(`(R,C`"0D)``E)24`)B8F`"<G)P`H*"@`
M*2DI`"HJ*@`K*RL`+"PL`"TM+0`N+BX`+R\O`#`P,``Q,3$`,C(R`#,S,P`T
M-#0`-34U`#8V-@`W-S<`.#@X`#DY.0`Z.CH`.SL[`#P\/``]/3T`/CX^`#\_
M/P!`0$``04%!`$)"0@!#0T,`1$1$`$5%10!&1D8`1T='`$A(2`!)24D`2DI*
M`$M+2P!,3$P`34U-`$Y.3@!/3T\`4%!0`%%140!24E(`4U-3`%145`!5554`
M5E96`%=75P!86%@`65E9`%I:6@!;6UL`7%Q<`%U=70!>7EX`7U]?`&!@8`!A
M86$`8F)B`&-C8P!D9&0`965E`&9F9@!G9V<`:&AH`&EI:0!J:FH`:VMK`&QL
M;`!M;6T`;FYN`&]O;P!P<'``<7%Q`')R<@!S<W,`='1T`'5U=0!V=G8`=W=W
M`'AX>`!Y>7D`>GIZ`'M[>P!\?'P`?7U]`'Y^?@!_?W\`@("``(&!@0""@H(`
M@X.#`(2$A`"%A84`AH:&`(>'AP"(B(@`B8F)`(J*B@"+BXL`C(R,`(V-C0".
MCHX`CX^/`)"0D`"1D9$`DI*2`).3DP"4E)0`E965`):6E@"7EY<`F)B8`)F9
MF0":FIH`FYN;`)R<G`"=G9T`GIZ>`)^?GP"@H*``H:&A`**BH@"CHZ,`I*2D
M`*6EI0"FIJ8`IZ>G`*BHJ`"IJ:D`JJJJ`*NKJP"LK*P`K:VM`*ZNK@"OKZ\`
ML+"P`+&QL0"RLK(`L[.S`+2TM`"UM;4`MK:V`+>WMP"XN+@`N;FY`+JZN@"[
MN[L`O+R\`+V]O0"^OKX`O[^_`,#`P`#!P<$`PL+"`,/#PP#$Q,0`Q<7%`,;&
MQ@#'Q\<`R,C(`,G)R0#*RLH`R\O+`,S,S`#-S<T`SL[.`,_/SP#0T-``T='1
M`-+2T@#3T],`U-34`-75U0#6UM8`U]?7`-C8V`#9V=D`VMK:`-O;VP#<W-P`
MW=W=`-[>W@#?W]\`X.#@`.'AX0#BXN(`X^/C`.3DY`#EY>4`YN;F`.?GYP#H
MZ.@`Z>GI`.KJZ@#KZ^L`[.SL`.WM[0#N[NX`[^_O`/#P\`#Q\?$`\O+R`//S
M\P#T]/0`]?7U`/;V]@#W]_<`^/CX`/GY^0#Z^OH`^_O[`/S\_`#]_?T`_O[^
M`/___P`T-#0\/#P\/#P\/#P\/#P\/#P\/#P\/#PL#`0$!`0$!%RTU-34U-34
MU-34U-S4U-34U-34U-34U+0T400$!`0$9,SL]/3T_/3\]/3T_/3\]/ST_/S\
M]/3LQ#11400$!`1DQ.3L]/3T]/3T]/3T]/3T]/3T]/3T[.R\-%%1400$!&3$
MY.SL[.3L[.SDY.3D[.SD[.3L[.SLY+PT45%1400$9+SD[.RLC*S4Q)24G)2,
MC)24E)R<G.S<O#1145%1401DO-SD[.3$492L9.2D3#0L7,3,4;34Y-R\-%%1
M45%1462\W.3D[.3D481TY(QLI)QLC+QTK-3DW+PT!`0$!`0$9+S<Y.3LY.2\
M48S4U(RLS'3,W*11Q.3<O#0$!`0$!`1DO-SDY.3DY-R,?)RT?(2<;,SDO'3$
MY-RT-`0$!`0$!%R\W-SDY.3DU)RD7)2,S#R49,R\C%'<U+0T!`0$!`0$9+34
MW-S<Y-R,C*PLO+3,6L1DG&R4I-S4M#0$!`0$!`1<M-3<W.3<W'24U$RD](P\
MU'24=)Q,W,RT-`0$!`0$!&2TU-S<W.3<=%'T=(3LS&3D?&RDM&RDU+0T!`0$
M!`0$9+3,W-S,?(R$M/S,Q/STM/R\9,RLA%&\K#0$!`0$!`1<M,S4S(RDW-SL
M_/S\_/ST_.RT[*Q\E%&L-`0$!`0$!%RLS,QLG/3\_/S\_/S\_/S\_/S\Q)2,
M4:PT!`0$!`0$7*S$O'SD_/S\_/S\_/S\_/S\_/SLS*Q1K#0$!`0$!`1<K+1,
MQ/S\_.ST_/S\_/S\_/S\_/2\4<2L-`0$!`0$!%RLM$S4_/STM-S\_/S\_/S\
M_/S\S%',Q*0T!`0$!`0$7*S$I%'\_/RTG/3\_/S\_/S\_/244<S$I"P$!`0$
M!`1<I*11A.S\_,QDM.S\_/S\_/S\U&RLS+RD-`0$!`0$!%RD9'2\]/S\Q%&$
MG.3\_/S\_.2,4<S,Q*0T!`0$!`0$7*1LC.3T_/R<4<Q1E.S\_/S\O'3,S,2\
MG"P$!`0$!`1<I*QD7&2DI%&LS,1TE.3T_.11O,S,Q+R<-`0$!`0$!%RDM+R\
MC%%1Q,3,S*Q1?'R4;'R\S,3$O)PL!`0$!`0$7)R\Q,3$Q,3$Q,3$Q,1145%1
MO,3$Q,2TG#0$!`0$!`14G+3$Q,3$Q,3$Q,3$Q,3$Q,3$Q,3$O+2<+`0$!`0$
M!%2<O,3$O+R\O+R\O+R\O+R\O+R\O+R\M)PL!`0$!`0$7)RTQ+RTM+2TM+2T
MM+2TM+2TM+2TM+2LG"P$!`0$!`14A)2<G)24E)24E)24E)24E)24E)24E)2$
M)`0$!`0$!$147%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%0T!`0$!`0$````/P``
M`!\````/````!P````,````!`````````#\````_````/P```#\````_````
M/P```#\````_````/P```#\````_````/P```#\````_````/P```#\````_
M````/P```#\````_````/P```#\````_````/P```#\```$``@`0$````0`(
M`&@%```!`"`@```!``@`J`@```(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!.0C$P`````$GSD4@!````8SI<4&5R;%QC<&%N7&)U
J:6QD7%!!4BU086-K97(M,"XY.#(M=VLU0VUO7&UY;&1R7'!A<BYP9&(`
